%%% Elhanan Helpman, Oleg Itskhoki, Marc-Andreas Muendler and Stephen J. Redding (2016):
%%% "Trade and Inequality: From Theory to Estimantion," Review of Economic Studies, forthcoming

%%% ROBUSTNESS OVER TIME (Figure H.10 in Online Supplement)

%%% First run mainMLE.m to generate ML Estimates written into THETA_MLE.csv
%%% Then run COUNTERFACTUAL.m and after this code



%% ------ ESTIMATED PARAMETERS ------
% indexes of the estimated parameters
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v
imh = 6;    % mu_h
imw = 7;    % mu_w
ifx = 8;    % f


%% ------ CALIBRATED PARAMETERS ------

% denoted as in the paper:
beta = 3/4;
gamma = 1/2;
k = 4/3;
tau = 1.6;


%% ------ DATA GENERATING PROCESS ------
% generating model-simulated dataset of firm employment, wages, export status

% Number of draws (use 10M for precision and 100K for fast calculation)
N = 500000;

% Shock draws for (u,v,z) across firms:
ZZZ = randn(N,3);




for t = 1:1998-1986+1
    
    yr = 1986+t-1;
    
    %% ------ ESTIMATED PARAMETERS ------
    
    % load data to calculate average employment and wages for alpha_h and alpha_w:
    ddd = csvread(sprintf('%s%d%s','/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-',yr,'-fun.csv'));
    H = log(ddd(:,11-1));  % log employment
    W = ddd(:,9-1);        % log wage (9 for FIRM FE PSI and 5 for MEAN LOG WAGE)
    hbar = mean(H);         % average log employment
    wbar = mean(W);         % average log wage
    
    % load estimated parameters
    THETA_MLE = csvread('THETA_MLE.csv');
    zt  = THETA_MLE(izt,t);
    muh = THETA_MLE(imh,t);
    muw = THETA_MLE(imw,t);
    ru  = THETA_MLE(iru,t);
    rv  = THETA_MLE(irv,t);
    su  = THETA_MLE(isu,t);
    sv  = THETA_MLE(isv,t);
    fx  = THETA_MLE(ifx,t);
    ah  = hbar - muh*(1-normcdf(fx,0,1));
    aw  = wbar - muw*(1-normcdf(fx,0,1));
    
    
    
    %% ------ CALIBRATED PARAMETERS ------
    delta = k * (1 + muh/muw);
    Gamma = 1 - beta*gamma - beta/delta*(1-gamma*k);
    % relative demand Ax/Ad:
    RD = ( exp(muh+muw)^(Gamma/(1-beta)) - 1 ) * tau^(beta/(1-beta)) ;
    
    
    
    %% ------ DATA GENERATING PROCESS ------
    % generating model-simulated dataset of firm employment, wages, export status
    % Shock draws for (u,v,z) across firms:
    SIGMA = [su^2 0 ru*su;
        0 sv^2 rv*sv;
        ru*su rv*sv 1];
    DDD = (ZZZ*SIGMA^(1/2));
    UU = DDD(:,1);  % u shock
    VV = DDD(:,2);  % v shock
    ZZ = DDD(:,3);  % z shock
    OM = zt*UU+VV;  % omega = zeta*u + v
    
    II = zeros(N,1);
    II(ZZ>=fx) = 1;         % firm export status
    HH = ah + muh*II + UU;  % firm employment
    WW = aw + muw*II + OM;  % firm wages
    
    % variance of log worker wages:
    % in counterfactual autarky:
    VARAUT = mean(OM.^2 .* exp(UU))/mean(exp(UU)) - (mean(OM .* exp(UU))/mean(exp(UU)))^2 ;
    % in estimated open-economy equilibrium:
    VAROPEN = mean(WW.^2 .* exp(HH))/mean(exp(HH)) ...
        - (mean( (WW) .* exp(HH))/mean(exp(HH)))^2 ;
    % relative standard deviation of log worker wages (relative to counterfactual autarky):
    CF = sqrt(VAROPEN/VARAUT);
    % exporter employment share in estimated open-economy equilibrium:
    SHH = II'*exp(HH)/sum(exp(HH));
    
    
    
    %% ------ VARIABLE TRADE COST COUNTERFACTUAL ------
    
    DATA = [];
    tic
    for mm=0:.01:5;    % use step 0.001 for precision and 0.01 for fast calculation
        
        % counterfactual values of mu_h, mu_w and f_x (see paper)
        muh0 = mm*muh;
        muw0 = mm*muw;
        fx0 = fx - (ru^2 + rv^2)/((1+zt)^2*su^2+sv^2) *( log(exp(muh0+muw0)-1) - log(exp(muh+muw)-1));
        
        % corresponding counterfactual export status, employment and wages of the firms
        II0 = zeros(N,1);
        II0(ZZ>=fx0) = 1;
        HH0 = ah + muh0*II0 + UU;
        WW0 = aw + muw0*II0 + OM;
        
        % variance of log worker wages in counterfactual open-economy equilibrium:
        VAROPEN0 = mean(WW0.^2 .* exp(HH0))/mean(exp(HH0)) ...
            - (mean( (WW0) .* exp(HH0))/mean(exp(HH0)))^2 ;
        % relative standard deviation of log worker wages in counterfactual equilibrium relative to counterfactual autarky:
        CF0 = sqrt(VAROPEN0/VARAUT);
        % exporter employment share in counterfactual open-economy equilibrium:
        SHH0 = II0'*exp(HH0)/sum(exp(HH0));
        % corresponding variable trade cost (see appendix to the paper):
        tau0 = ( ( exp(muh0+muw0)^(Gamma/(1-beta)) - 1 )/RD )^(-(1-beta)/beta) ;
        
        DATA = [DATA; [SHH0 CF0 tau0]];
        
    end
    toc
    
    
    
    %% ------ PLOT VARIABLE TRADE COST COUNTERFACTUAL ------
    
    % Subplot (b) for variable trade cost
    figure(32)
    plot(DATA(:,1),max(DATA(:,2),1))
    hold on
    pause(.1)
    
    
    
    
    %% ------ FIXED TRADE COST COUNTERFACTUAL ------
    
    DATA2 = [];
    tic
    for fx0=-3:.025:5;  % use step 0.0025 for precision and 0.025 for fast calculation
        
        % generating counterfactual firm data based on counterfactual fixed cost fx0
        II0 = zeros(N,1);
        II0(ZZ>=fx0) = 1;
        HH0 = ah + muh*II0 + UU;
        WW0 = aw + muw*II0 + OM;
        
        % variance of log worker wages in counterfactual open-economy equilibrium:
        VAROPEN0 = mean(WW0.^2 .* exp(HH0))/mean(exp(HH0)) ...
            - (mean( (WW0) .* exp(HH0))/mean(exp(HH0)))^2 ;
        % relative standard deviation of log worker wages in counterfactual equilibrium relative to counterfactual autarky:
        CF0 = sqrt(VAROPEN0/VARAUT);
        % exporter employment share in counterfactual open-economy equilibrium:
        SHH0 = II0'*exp(HH0)/sum(exp(HH0));
        
        DATA2 = [DATA2; [SHH0 CF0]];
        
    end
    toc
    
    
    % Subplot (a) for fixed trade cost
    figure(31)
    plot(DATA2(:,1),max(DATA2(:,2),1))
    hold on
    pause(.1)
    
    
end


% Subplot (b) for variable trade cost
figure(32)
xlabel('Exporter employment share','FontSize',16,'interpreter','latex')
ylabel('Wage inequality (\% increase)','FontSize',16,'interpreter','latex')
set(gca,'FontSize',14)
axis([0 1 1 1.2])
set(gca,'xtick',[0:.2:1])
set(gca,'ytick',[1:.05:1.2])
set(gca,'yticklabel',[0:5:20])

print -depsc robustness_tau.eps



% Subplot (a) for fixed trade cost
figure(31)
xlabel('Exporter employment share','FontSize',16,'interpreter','latex')
ylabel('Wage inequality (\% increase)','FontSize',16,'interpreter','latex')
set(gca,'FontSize',14)
axis([0 1 1 1.12])
set(gca,'xtick',[0:.2:1])
set(gca,'ytick',[1:.025:1.1 1.12])
set(gca,'yticklabel',[0:2.5:10 12])

print -depsc robustness_fx.eps